imblearn.ensemble.BalanceCascade
================================

.. currentmodule:: imblearn.ensemble

.. autoclass:: BalanceCascade

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BalanceCascade.__init__
      ~BalanceCascade.fit
      ~BalanceCascade.fit_sample
      ~BalanceCascade.get_params
      ~BalanceCascade.sample
      ~BalanceCascade.set_params
   
   

   
   
   